import argparse
import os

import pandas as pd
from pymongo import MongoClient

from uw_file_processor_api.workflows.steps.commons.scripts import get_and_validate_body

SALES_COLLECTION = 'sales'

PROCESS_ALL_BY_KEYS_COLLECTION = 'process_all_by_keys'


def main():
    parser = argparse.ArgumentParser(description="Process args.")

    parser.add_argument('--body', type=str, help='body of the request', required=True)
    parser.add_argument('--item-data-path', type=str, help='item data path to process',
                        default='/data/item_data.parquet')

    args = parser.parse_args()

    try:
        body = get_and_validate_body(args.body)

        mongo_connection_string = os.getenv('MONGO_CONNECTION_STRING',
                                            'mongodb://localhost:27017/?directConnection=true')

        mongo_client = MongoClient(mongo_connection_string)

        tenant_db_name = f'client-{body["tenant"]}'
        mongo_db = mongo_client[tenant_db_name]
        mongo_collection_sales = mongo_db[SALES_COLLECTION]

        mongo_collection_process_all_by_keys = mongo_db[PROCESS_ALL_BY_KEYS_COLLECTION]

        item_status = mongo_collection_process_all_by_keys.find_one(body['filters'])

        if item_status is not None:
            if item_status['status'] != 'Pending':
                raise Exception(f'Item status is {item_status["status"]}')

        documents = []
        for document in mongo_collection_sales.find(body['filters']):
            documents.append(document)

        df = pd.DataFrame(documents)

        if df.empty:
            raise Exception('No data found')

        print('dataframe head:\n', df.head())

        df = df.drop(columns=['_id'])

        df.to_parquet(args.item_data_path, engine='pyarrow', index=False)

    except Exception as e:
        print(f'Error downloading file: {e}')
        raise e

    print('File downloaded successfully')


if __name__ == "__main__":
    main()
