import argparse

from uw_file_processor_api.workflows.steps.commons.scripts import get_item_data_from_local_file, \
    generate_arima_forecast, save_data_in_local, get_and_validate_body


def main():
    parser = argparse.ArgumentParser(description="Process args.")

    parser.add_argument('--body', type=str, help='body of the request', required=True)
    parser.add_argument('--prepared-files-path', type=str, help='path to prepared files',
                        default='/data/prepared_files.parquet')
    parser.add_argument('--arima-forecast-path', type=str, help='path to arima forecast',
                        default='/data/arima_forecast.parquet')

    args = parser.parse_args()

    try:
        df = get_item_data_from_local_file(args.prepared_files_path)

        if df.empty:
            raise Exception('No data found')

        df_forecast = generate_arima_forecast(df)

        if df_forecast.empty:
            raise Exception('No forecast generated')

        body = get_and_validate_body(args.body)

        for key, value in body['filters'].items():
            df_forecast[key] = value

        save_data_in_local(df_forecast.reset_index(), args.arima_forecast_path)

        print('dataframe head:\n', df_forecast.head())

    except Exception as e:
        print(f'Error processing file: {e}')
        raise e


if __name__ == "__main__":
    main()
