import argparse

from uw_file_processor_api.workflows.steps.commons.scripts import get_item_data_from_local_file, preparing_data, \
    save_data_in_local


def main():
    parser = argparse.ArgumentParser(description="Process args.")

    parser.add_argument('--item-data-path', type=str, help='item data path to process',
                        default='/data/item_data.parquet')
    parser.add_argument('--prepared-files-path', type=str, help='prepared files path to save',
                        default='/data/prepared_files.parquet')

    args = parser.parse_args()

    try:
        df = get_item_data_from_local_file(args.item_data_path)

        if df.empty:
            raise Exception('No data found')

        df_prepared = preparing_data(df)

        if df_prepared.empty:
            raise Exception('No data found')

        print('dataframe head:\n', df_prepared.head())

        save_data_in_local(df_prepared, args.prepared_files_path)

        print('dataframe saved successfully')

    except Exception as e:
        print(f'error in preparing data to prediction: {e}')
        raise e


if __name__ == "__main__":
    main()
