import argparse
import json
import os
from datetime import datetime

from pymongo import MongoClient

PROCESS_ALL_BY_KEYS_COLLECTION = 'process_all_by_keys'


def main():
    parser = argparse.ArgumentParser(description="Process args.")

    parser.add_argument('--body', type=str, help='body of the request', required=True)
    parser.add_argument('--status', type=str, help='status to save', required=True)
    parser.add_argument('--exception', type=str, help='exception to save', default='')

    args = parser.parse_args()

    try:
        body = json.loads(args.body)

        if 'tenant' not in body:
            raise Exception('No tenant found in body')

        if 'filters' not in body:
            raise Exception('No filters found in body')

        mongo_connection_string = os.getenv('MONGO_CONNECTION_STRING',
                                            'mongodb://localhost:27017/?directConnection=true')

        mongo_client = MongoClient(mongo_connection_string)

        mongo_db_name = f'client-{body["tenant"]}'
        mongo_db = mongo_client[mongo_db_name]
        mongo_collection_process_all_by_keys = mongo_db[PROCESS_ALL_BY_KEYS_COLLECTION]

        body_to_save = {
            'status': args.status,
            'created_at': datetime.now(),
        }

        # for key, value in body['filters'].items():
        #     body_to_save[key] = value

        if args.exception not in ('', None):
            body_to_save['exception'] = args.exception

        updated_items = mongo_collection_process_all_by_keys.update_one(
            filter=body['filters'],
            update={'$set': body_to_save},
            upsert=True
        )

        print(f'updated items count: {updated_items.modified_count}')

    except Exception as e:
        print(f'error saving status: {e}')
        raise e

    print('status saved successfully')


if __name__ == "__main__":
    main()
