import argparse
import json
import os


def main():
    parser = argparse.ArgumentParser(description="Process args.")

    parser.add_argument('--body', type=str, help='body to process', required=True)

    args = parser.parse_args()

    try:
        data = json.loads(args.body)

        path = f"/data/outputs"

        if not os.path.exists(path):
            os.makedirs(path, exist_ok=True)

        for key, value in data.items():
            file_path = os.path.join(path, f"{key}.txt")

            with open(file_path, "w") as file:
                # verify value is dict
                if isinstance(value, dict):
                    file.write(json.dumps(value))
                    print(f'Wrote dict {value} to file {file_path}')
                # verify value is number
                elif isinstance(value, (int, float)):
                    file.write(str(value))
                    print(f'Wrote int or float {value} to file {file_path}')
                else:
                    file.write(value)
                    print(f'Wrote {value} to file {file_path}')

    except Exception as e:
        print(f'Error processing body: {e}')
        raise e


if __name__ == "__main__":
    main()
