import json
import sys
import os

import pytest
from os import path

from .get_item_for_processing import main as get_item_for_processing
from .prediction_with_arima_model import main as prediction_with_arima_model
from .preparing_data_to_prediction import main as preparing_data_to_prediction
from .process_seasonal_decompose import main as process_seasonal_decompose
from .save_result_in_db import main as save_result_in_db
from .process_item_save_status import main as process_item_save_status
from uw_file_processor_api.workflows.services.item_processor_service import ItemProcessorService


# Teste para a função
def test_download_item_data():

    base_path_files = '/home/lffranca/go/src/gitlab.com/upowl/back/uw-file-processor-api/data/vdc'

    tenant = 'vdc'
    keys = ['state', 'product_id']

    item_processor_service = ItemProcessorService(tenant, keys)

    items = item_processor_service.get_to_process_items_by_keys()

    for index, item in enumerate(items):
        path_item = ''
        filters = {}
        for key in keys:
            filters[key] = item[key]
            if path_item == '':
                path_item = item[key]
            else:
                path_item = path.join(path_item, f'{item[key]}')

        body = {
            "tenant": tenant,
            "filters": filters
        }

        item_base_path = path.join(base_path_files, path_item)

        if not path.exists(item_base_path):
            os.makedirs(item_base_path)

        item_data_path = path.join(item_base_path, 'item_data.parquet')
        prepared_files_path = path.join(item_base_path, 'prepared_files.parquet')
        arima_forecast_path = path.join(item_base_path, 'arima_forecast.parquet')
        seasonal_decompose_path = path.join(item_base_path, 'seasonal_decompose.parquet')

        exception = None
        try:
            # get item data
            sys.argv = [
                'get_item_for_processing.py',
                '--body', json.dumps(body),
                '--item-data-path', item_data_path
            ]

            get_item_for_processing()

            # prepare data
            sys.argv = [
                'preparing_data_to_prediction.py',
                '--item-data-path', item_data_path,
                '--prepared-files-path', prepared_files_path,
            ]

            preparing_data_to_prediction()

            # prediction with arima model
            sys.argv = [
                'prediction_with_arima_model.py',
                '--body', json.dumps(body),
                '--prepared-files-path', prepared_files_path,
                '--arima-forecast-path', arima_forecast_path,
            ]

            prediction_with_arima_model()

            sys.argv = [
                'seasonal_decompose_path.py',
                '--body', json.dumps(body),
                '--period', "6",
                '--prepared-files-path', prepared_files_path,
                '--seasonal-decompose-path', seasonal_decompose_path,
            ]

            process_seasonal_decompose()

            sys.argv = [
                'save_result_in_db.py',
                '--body', json.dumps(body),
                '--prepared-files-path', prepared_files_path,
                '--arima-forecast-path', arima_forecast_path,
                '--seasonal-decompose-path', seasonal_decompose_path,
            ]

            save_result_in_db()

        except Exception as e:
            exception = str(e)

        status = 'Succeeded'
        if exception:
            status = 'Failed'

        sys.argv = [
            'process_item_save_status.py',
            '--body', json.dumps(body),
            '--status', status,
            '--exception', exception,
        ]

        process_item_save_status()

        print(f'processed item {index + 1} of {len(items)}')


if __name__ == "__main__":
    pytest.main()
